**g2m-api-client** is a Python client designed to interface with G2M Insights' _Analyzr API_, a state-of-the-art machine learning platform delivering custom predictive analytics in a single-tenant environment for B2B sales and marketing analysts.

## Requirements
The client requires credentials to access the Analyzr API. For more information contact your account representative or reach out to your support team at support@g2m.ai. The client also requires the following dependencies:
* Python (>=3.7)
* Scikit-learn (>=1.0)

## Installation
The easiest way to install `g2m-api-client` is using `pip`:
```
pip install g2m-api-client
```

_Last Updated: 10/17/2021_
